@@ -201,8 +201,8 @@ sub get {
 							'align-on-begin' => 'Align On Begin',
 							'block-on-right-margin' => 'Blockformat On Right Margin',
 							'block-on-width' => 'Blockformat On Width ...',
-							'linewrap-on-right-margin' => 'Linebreaks Before Right Margin',
-							'linewrap-on-width' => 'Linebreaks Before Width ...',
+							'linewrap-on-right-margin' => 'Wrap Lines Exceeding Right Margin',
+							'linewrap-on-width' => 'Wrap Lines Exceeding Fixed Width ...',
 							'indent-char' => 'Indent Space',
 							'dedent-char' => 'Dedent Space',
 							'indent-tab' => 'Indent Tab',
@@ -224,10 +224,10 @@ sub get {
 							indent2spaces => 'Indention 2 Whitespace',
 							indent2tabs => 'Indention 2 Tab',
 							spaces2tabs => 'Spaces 2 Tabs',
-							tabs2spaces => 'Tabs 2 Whitespace',
+							tabs2spaces => 'Tabs 2 Spaces',
 						},
 						format => {
-							'del-trailing-whitespace' => 'Delete Trailing',
+							'del-trailing-whitespace' => 'Delete Trailing Whitespace',
 						},
 					},
 				},
@@ -243,7 +243,7 @@ sub get {
 						'regex-switch' => 'Regular Expression',
 						match => {
 							'case-switch' => 'Match Case',
-							'whole-word-switch' => 'Whole Word only',
+							'whole-word-switch' => 'Whole Word Only',
 							'word-begin-switch' => 'Word Begin',
 						},
 					},
@@ -265,7 +265,7 @@ sub get {
 					prev => 'Replace Backward',
 					'next' => 'Replace Forward',
 					all => 'Replace All',
-					'with-confirm' => 'Replace With Confirm',
+					'with-confirm' => 'Replace With Confirmation',
 					selection => 'Replace Into Selection',
 				},
 				goto => {
@@ -326,9 +326,9 @@ sub get {
 						'insert-last-var' => 'Insert Var',
 						'copy-string' => 'Copy String',
 					},
-					'auto-indention' => 'Autoindention',
-					'brace-indention' => 'Braceindention',
-					'brace-completion' => 'Bracecompletion',
+					'auto-indention' => 'Auto-Indention',
+					'brace-indention' => 'Brace-Indention',
+					'brace-completion' => 'Brace-Completion',
 				},
 				document => {
 					EOL => {
@@ -580,41 +580,41 @@ sub get {
 				},
 				file => {
 					new => 'opens a new empty text',
-					open => 'display an existing textfile as a new document',
-					'open-dir' => 'open all files of this directory',
-					reload => 'read file from hard drive and replace content with displayed',
+					open => 'opens an existing file',
+					'open-dir' => 'open all files of a chosen directory',
+					reload => 'reload file from disc',
 					'reload-all' => 'reload all opened files',
 					rename => 'change current files name',
 					insert => 'insert file content at caret position',
-					close => {
-						current => 'close current document, if preset the file will be saved',
-						all => 'close all open documents',
-						other => 'close all open documents but not the current visible',
-						unsaved => 'close current document without save it before it',
-					'all-unsaved' => 'close all document without save it before it',
-						'other-unsaved' => 'unsaved closing of all open docs but not the current visible',
-					},
 					save =>{
-						current => 'save the displayed state of the current file',
-						all => 'save all the currently opened files',
+						current => 'save current file',
+						all => 'save all open files',
 						as => 'save current document under different file name',
 						'copy-as' => 'save doc with different name, keep current version open',
 					},
+					close => {
+						current => 'close current document, if present the file will be saved',
+						all => 'close all open documents',
+						other => 'close all open documents but the current',
+						unsaved => 'close current document without saving',
+						'all-unsaved' => 'close all documents without saving',
+						'other-unsaved' => 'close all open docs but the current without saving',
+					},
 					print => 'print the current document',
 					session => {
-						open => 'restore an once saved file session',
-						add => 'add files of a saved file session',
-						save => 'save order and properties of this file session',
-						import => 'open files session from another editors format',
-						export => 'save files session in another editors format',
+						open => 'restore a saved file session',
+						add => 'add files from a saved file session',
+						save => ' save current file session',
+						import => 'open file session from another editors format',
+						export => 'save file session in another editors format',
 						'backup-open' => 'restore the backup session',
-						'backup-save' => 'remember current files as the backup session',
+						'backup-save' => 'set current files as the backup session',
 						'history-open-all' => 'restore all listed closed files from history',
 					},
 				},
 				edit => {
 					changes => {
-						undo => 'undo the last change in the current document',
+						undo => 'undo the last change of the current document',
 						redo => 'redo the last change made undone',
 						'undo-several' => 'go several steps back in edit history',
 						'redo-several' => 'go several steps forward in edit history',
@@ -778,7 +778,7 @@ sub get {
 				tool => {
 					note => 'jump to the notepad',
 					'note-selection' => 'paste selected text on the end of the notepad',
-					'interpreter-run-document' => 'run current programm and show result in output panel',
+					'interpreter-run-document' => 'run current program and show result in output panel',
 					'interpreter-stop-document' => 'stop the current running output panel process',
 					'output' => {
 						'inc' => 'display the include paths of the Perl Interpreter in the ouput panel',
